@@ -507,24 +507,58 @@ gchar *libutils_get_name_without_ext( gchar *p_PathNameFile )
 	return( (gchar *)NewName );
 }
 // 
-// RETOURNE LE NOMBRE DE PROCESSUS ACTIF
-// http://geekiroxx.free.fr/weblog/index.php?article8/fonction-c-retournant-le-nombre-de-processus-actif-linux
+// RETOURNE LE NOMBRE DE PROCESSUS ACTIF POUR: p_NameFile
+// EX:
+//	if( libutils_getNbProcess( "xcfa" ) > 1 )
+//	if( libutils_getNbProcess( "tm" ) > 1 )
 // 
-gint libutils_getNbProcess( void )
+gint libutils_getNbProcess( gchar *p_NameFile )
 {
-	struct dirent	*Read;
-	DIR		*Repo;
-	gint		pNbr = 0;
+	size_t 		SizeFile;
+	gchar		*Buffer = NULL;
+	FILE		*fp = NULL;
+	gchar		**LarrbufLine = NULL;
+	gchar		**LarrbufWord = NULL;
+	gint		Cpt = 0;
+	gchar		*CommandLine = NULL;
+	gchar		*PathNameFile = NULL;
+		
+	if( TRUE == libutils_find_file( "pidof" ) ) {
+		
+		PathNameFile = g_strdup_printf( "/tmp/process_%s", p_NameFile );
+		CommandLine  = g_strdup_printf( "pidof %s > %s", p_NameFile, PathNameFile );
+		system( CommandLine );
+		g_free( CommandLine );
+		CommandLine = NULL;
+		// g_print( "getpid(void) = %d\n", getpid() );
 	
-	Repo = opendir("/proc");
-	while( (Read = readdir(Repo)) )  {
-		if( atoi(Read->d_name) > 0 && atoi(Read->d_name) < 32768 )  {
-			// g_print( "[ %4d ] Read->d_name = %s\n", pNbr+1, Read->d_name );
-			pNbr ++;
+		if(( SizeFile = libutils_get_size_file( PathNameFile )) > 0 ) {
+			if( NULL != ( fp = fopen( PathNameFile, "r" ))) {
+			
+				Buffer = (gchar *)g_malloc0( sizeof(gchar) * ( SizeFile +10 ));
+				SizeFile = fread( Buffer, SizeFile, 1, fp );
+				fclose( fp );
+			
+				LarrbufLine = g_strsplit( Buffer, "\n", 0 );
+				g_free( Buffer );
+				Buffer = NULL;
+			
+				LarrbufWord = g_strsplit( LarrbufLine[ 0 ], " ", 0 );
+				for( Cpt = 0; LarrbufWord[ Cpt ]; Cpt++ );
+			
+				g_strfreev( LarrbufWord );
+				LarrbufWord = NULL;
+				g_strfreev( LarrbufLine );
+				LarrbufLine = NULL;
+			}
 		}
+		g_unlink( PathNameFile );
+		g_free( PathNameFile );
+		PathNameFile = NULL;
+		
 	}
-	closedir( Repo );
-	return( pNbr );
+	
+	return( Cpt );
 }
 // 
 // 
@@ -544,4 +578,3 @@ gchar *libutils_string_toupper( gchar *p_str )
 
 
 
-
