@@ -91,7 +91,7 @@ gchar		*libutils_get_name_without_ext_with_amp( gchar *p_PathNameFile );
 gchar		*libutils_get_name_without_ext( gchar *p_PathNameFile );
 gchar		*libutils_create_temporary_rep (gchar *SrcTmp, gchar *NewRepTmp);
 gchar		*libutils_remove_temporary_rep (gchar *path_tmprep);
-gint		libutils_getNbProcess( void );
+gint		libutils_getNbProcess( gchar *p_NameFile );
 gchar		*libutils_string_toupper( gchar *p_str );
 
 // COMBO.C
