@@ -29,11 +29,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <stdio.h>
@@ -545,7 +540,7 @@ gboolean dvd_event_click_mouse (GtkWidget *treeview, GdkEventButton *event, gpoi
 	GtkTreeViewColumn  *column;
 	GtkTreeViewColumn  *ColumnDum;
 	gint                i;
-	guint               button;
+	// guint               button;
 	GtkTreeModel       *model = (GtkTreeModel *)data;
 	GtkTreeIter         iter;
 	VAR                *var = NULL;
@@ -617,7 +612,7 @@ gboolean dvd_event_click_mouse (GtkWidget *treeview, GdkEventButton *event, gpoi
 
 	if (var && (var->type_list_dvd == _DVD_DATA || var->type_list_dvd == _DVD_DATA_ALL)) {
 
-		button = ((GdkEventButton*)event)->button;
+		// button = ((GdkEventButton*)event)->button;
 		if (bool_click_droit && BoolSelectColNormalise == TRUE) {
 			popup_normalise_dvd ();
 		}
@@ -681,6 +676,7 @@ gboolean dvd_event_click_mouse (GtkWidget *treeview, GdkEventButton *event, gpoi
 			if (TRUE == mplayer_is_used ()) {
 
 				wininfo_create (
+					WindMain,
 					_("MPLAYER deja en action"),
 					_("MPLAYER est deja utilise  !!"),
 					  "");
@@ -1324,6 +1320,7 @@ void dvd_reffresh_list_dvd_action (void)
 	if (TRUE == mplayer_is_used ()) {
 
 		wininfo_create (
+			WindMain,
 			_("MPLAYER deja en action"),
 			_("MPLAYER est deja utilise  !!"),
 			  "");
@@ -1333,7 +1330,7 @@ void dvd_reffresh_list_dvd_action (void)
 	dvd_remove_GtkTree ();
 
 	var_dvd.PathDvd = scan_get_text_combo_cd (_DVD_);
-	g_print("---------------> var_dvd.PathDvd = %s\n",var_dvd.PathDvd );
+	// g_print("---------------> var_dvd.PathDvd = %s\n",var_dvd.PathDvd );
 	
 	WindScan_open (_("Scan ..."), WINDSCAN_PULSE);
 	
@@ -1384,11 +1381,12 @@ void dvd_reffresh_list_dvd (void)
 	if (libutils_find_file ("lsdvd") == FALSE) {
 
 		wininfo_create (
+			WindMain,
 			_("lsdvd est absent  !"),
 			_("Il faut installer le programme: lsdvd"),
 			  "");
 
-		g_print("VEUILLEZ INSTALLER L APPLICATION [ LSDVD  ]\n");
+		// g_print("VEUILLEZ INSTALLER L APPLICATION [ LSDVD  ]\n");
 		return;
 	}
 
@@ -1489,7 +1487,8 @@ gboolean dvd_foreach_func (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *
 				}
 			}
 			else if (var->format_id == _INCONNU_) {
-				g_print ("\nFORMAT == _INCONNU_\n\tExtraction comme AC3\n");
+				if( TRUE == OptionsCommandLine.BoolVerboseMode )
+					g_print ("\nFORMAT == _INCONNU_\n\tExtraction comme AC3\n");
 
 				ptr = dvdtable_get (var->OldChannels, var->NewChannels);
 				param = g_strdup_printf ("-channels %d -af pan=%d:%s",
