@@ -29,11 +29,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -225,7 +220,6 @@ void fileanalyze_recherche_recursive (gchar *Directory)
 	DIR    *dp;
 	struct  dirent *entry;
 	struct  stat statbuf;
-	gint	Dummy;
 	
 	// PRINT_FUNC_LF();
 	
@@ -240,7 +234,7 @@ void fileanalyze_recherche_recursive (gchar *Directory)
 		return;
 	}
 		
-	Dummy = chdir (Directory);
+	chdir (Directory);
 	while ((entry = readdir (dp)) != NULL) {
 		
 		if (WindScan_close_request () == TRUE) break;
@@ -283,7 +277,7 @@ void fileanalyze_recherche_recursive (gchar *Directory)
 			}
 		}
 	}
-	Dummy = chdir ("..");
+	chdir ("..");
 	closedir (dp);
 }
 // 
@@ -465,7 +459,6 @@ void fileanalyze_set_in_list (void)
 	GList		*List = NULL;
 	DETAIL		*detail = NULL;
 	VAR_LIST_FILES	*VarListFiles = NULL;
-	gint		 Cpt;
 	
 	List = g_list_first (VarAnalyze.ListFiles);
 	while (List) {
@@ -516,12 +509,14 @@ void fileanalyze_set_in_list (void)
 				detail->Etat_ReplayGain = RPG_ATTENTE;
 			}
 			
-			detail->TypeMp3Ogg.BoolChanged = FALSE;
-			detail->TypeMp3Ogg.type        = -1;
-			for (Cpt = 0; Cpt < 4; Cpt ++) {
-				detail->TypeMp3Ogg.debit [ Cpt ] = -1;
-				detail->TypeMp3Ogg.mode  [ Cpt ] = -1;
-			}
+			// MP3: DEBIT MODE
+			detail->Mp3_Debit    = -1;
+			detail->Mp3_Mode     = -1;
+			// OGG: DEBIT MANAGED DOWNMIX
+			detail->Ogg_Debit    = -1;
+			detail->Ogg_Managed  = -1;
+			detail->Ogg_Downmix  = -1;
+			detail->BoolChanged  = FALSE;
 			
 			if (VarListFiles->TypeFileIs == FILE_IS_FLAC)         detail->info = tagsflac_get_info (detail);
 			else if (VarListFiles->TypeFileIs == FILE_IS_WAV)     detail->info = tagswav_get_info (detail->namefile);
@@ -621,6 +616,7 @@ static gint fileanalyze_timeout (gpointer data)
 		
 		if (TRUE == VarAnalyze.BoolNoFindCheckMp3) {
 			wininfo_create (
+				WindMain,
 				_("Package checkmp3 (mp3check) NOT FOUND !"),
 				_("Veuillez installer checkmp3 ou mp3check pour\nla prise en compte des fichiers mp3"),
 			  	"");
