@@ -29,11 +29,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 // /usr/include/gtk-2.0/gdk/gdkkeysyms.h
 #include <gdk/gdkkeysyms.h>
@@ -44,11 +39,21 @@
 #include <getopt.h>
 #include <unistd.h>
 #include <sys/types.h>
+#include <locale.h>
+
+/* For the workspace/viewport stuff */
+#ifdef GDK_WINDOWING_X11
+#include <gdk/gdkx.h>
+#include <X11/Xlib.h>
+#include <X11/Xutil.h>
+#include <X11/Xatom.h>
+#endif
 
 #ifdef ENABLE_STATIC_LIBRARY
 	#include "../lib/lib.h"
 #endif
 
+#include "global.h"
 #include "options.h"
 #include "configuser.h"
 #include "file.h"
@@ -70,7 +75,7 @@
 #include "popup_systray.h"
 #include "statusbar.h"
 #include "cd_curl.h"
-#include "global.h"
+#include "bacon.h"
 
 // FIXME
 // TODO
@@ -79,6 +84,7 @@ GtkBuilder	*GtkXcfaProjet = NULL;
 GtkWidget	*WindMain = NULL;
 HOST_CONF	 HostConf;
 GtkWidget	*AdrLabelStatusbarGlobal = NULL;
+BaconMessageConnection *connection;
 
 
 KEYS keys = {
@@ -379,11 +385,18 @@ void segfault_handler(int sig)
 }
 // 
 // 
-void AnalyseCommandLine_set_argv (int argc, gchar *argv[])
+typedef enum {
+	_PARAMS_GET_ALL_OPTIONS_ = 0,
+	_PARAMS_GET_OPTIONS_ONLY_
+} PARAMS_CMD_LINE;
+// 
+// 
+GList *AnalyseCommandLine_set_argv( gint argc, gchar *argv[], PARAMS_CMD_LINE ParamsCmdLine )
 {
 	gint	 i;
 	gchar	*str_current_dir = NULL;
-	FILE	*fp = NULL;
+	// FILE	*fp = NULL;
+	GList	*GListFile = NULL;
 		
 	if( optind < argc ) {
 		
@@ -409,30 +422,73 @@ void AnalyseCommandLine_set_argv (int argc, gchar *argv[])
 				OptionsCommandLine.BoolHelpMode = TRUE;
 			}
 		}
+		
+		// STOP ?
+		if( _PARAMS_GET_OPTIONS_ONLY_ == ParamsCmdLine )return( (GList *)NULL );
+		
 		if( FALSE == OptionsCommandLine.BoolVerboseMode && FALSE == OptionsCommandLine.BoolVersionMode ) {
 			str_current_dir = g_get_current_dir();
-			fp = fopen( XCFA_FILE_LOAD, "a" );
+			// fp = fopen( XCFA_FILE_LOAD, "a" );
 			for( i = optind; i < argc; i++ )
-			{
+			{				
+				if( *argv[ i ] == '-' ) continue;
+				
 				// FROM DESKTOP
 				if( argv[i][0] == '/' ) {
 
-					fprintf( fp, "%s\n", argv[ i ] );
+					// fprintf( fp, "%s\n", argv[ i ] );
+					GListFile = g_list_append( GListFile, g_strdup( argv[ i ] ));
 				}
 				else {
 					gchar *str = NULL;
 				
 					str = g_strdup_printf( "%s/%s", str_current_dir, argv[i] );
-					fprintf( fp, "%s\n", str );
+					// fprintf( fp, "%s\n", str );
+					GListFile = g_list_append( GListFile, g_strdup( str ));
 					g_free( str );
 					str = NULL;
 				}
 			}
-			fclose( fp );
+			// fclose( fp );
 			g_free( str_current_dir );
 			str_current_dir = NULL;
 		}
 	}
+	return( (GList *)GListFile );
+}
+// 
+// 
+void main_save( GList *p_GListFile )
+{
+	GList   *list = NULL;
+	gchar	*PtrName = NULL;
+	FILE	*fp = NULL;
+	
+	// g_return_if_fail (p_GListFile != NULL);
+	if( NULL != p_GListFile ) {
+		if( NULL != (list = g_list_first( p_GListFile ))) {
+			fp = fopen( XCFA_FILE_LOAD, "a" );
+			while( list ) {
+				if (NULL != (PtrName = (gchar *)list->data)) {
+					fprintf( fp, "%s\n", PtrName );
+					g_print( "%s\n", PtrName );
+				}
+				list = g_list_next( list );
+			}
+			fclose( fp );
+		}
+	}
+}
+// 
+// 
+static void on_message_received( const char *message, gpointer data )
+{
+	FILE	*fp = NULL;
+	
+	fp = fopen( XCFA_FILE_LOAD, "a" );
+	fprintf( fp, "%s\n", message );
+	fclose( fp );
+	gtk_window_present (GTK_WINDOW (WindMain));
 }
 /* gint main (gint argc, gchar *argv[], gchar **envp)
  *
@@ -448,20 +504,12 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	gchar	*PathShareProjet = NULL;
 	gchar	*Path = NULL;
 	gchar	*PackageVersion = NULL;
+	GList	*GListFile = NULL;
 
-	if (TRUE == process_exist_file ()) {
-		AnalyseCommandLine_set_argv (argc, &argv[0]);		// Get and save param-file
-		return (EXIT_SUCCESS);					// Quit process with success
-	}
-	else {
-		g_unlink (XCFA_FILE_LOAD);				// Del paramter file if exist
-		AnalyseCommandLine_set_argv (argc, &argv[0]);		// Get and save param-file
+	/* Init type system as soon as possible */
+	g_type_init ();
+	g_set_prgname ("xcfa");
 		
-		// PLACER CET APPEL JUSTE AVANT: gtk_main ();
-		// 
-		// process_goto_timeout ();
-	}
-	
 	g_print ("%s :: %s (line = %d)\n", __FILE__, __FUNCTION__, __LINE__);
 	g_print ("\n");
 	g_print ("***************************\n");
@@ -474,6 +522,9 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	g_print ("Glib version = %d.%d.%d\n", GLIB_MAJOR_VERSION, GLIB_MICRO_VERSION, GLIB_MINOR_VERSION);
 	g_print ("***************************\n\n");
 	
+	// ANALYSE UNIQUEMENT LES OPTIONS
+	AnalyseCommandLine_set_argv( argc, &argv[0], _PARAMS_GET_OPTIONS_ONLY_ );
+	
 	if( TRUE == OptionsCommandLine.BoolVersionMode || TRUE == OptionsCommandLine.BoolHelpMode ) {
 		if( TRUE == OptionsCommandLine.BoolHelpMode ) {
 			g_print( "HELP MODE:\n");
@@ -500,14 +551,8 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 #else
 	// g_error ("ENABLE_NLS IS NOT OK\n\n");
 #endif
+	
 	GetInfo_cpu_print ();
-	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
-		g_print ("\n");
-		g_print ("HostConf.NbCpu   = %d CPU\n", HostConf.NbCpu);
-		g_print ("HostConf.TypeCpu = %d Bits\n", HostConf.TypeCpu);
-		g_print ("HostConf.Machine = %s\n", HostConf.Machine);
-		g_print ("\n");
-	}
 	
 	/* IF Segmentation fault */
 	signal (SIGSEGV, segfault_handler);
@@ -516,9 +561,53 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	
 	gtk_set_locale ();
 	gtk_init (&argc, &argv);
-	gdk_threads_enter ();
+
+	/*
+	Code revu depuis:
+		bacon-message-connection.c bacon-message-connection.h
+		Copyright (C) 2003
+		Bastien Nocera <hadess@hadess.net>
+	LA connection PEUT ETRE LIBEREE DES LE CHARGEMENT TOTAL DEPUIS LA LIGNE DE COMMANDE
+	LES FICHIERS SERONT PRIT EN COMPTE DEPUIS:
+		process_goto_timeout()
+	*/
+	connection = bacon_message_connection_new( "xcfa" );
+	if( NULL != connection )
+	{
+		if( FALSE == bacon_message_connection_get_is_server( connection )) 
+		{
+			// g_print( "\nCLIENT:\nGET COMMAND LINE AND EXIT\n" );
+			GListFile = AnalyseCommandLine_set_argv( argc, &argv[0], _PARAMS_GET_ALL_OPTIONS_ );		// Get and save param-file
+			// SEND WITH:
+			//	bacon_message_connection_send( connection, str );
+			bacon_message_connection_send( connection, GListFile );
+			GListFile = libutils_remove_glist( GListFile );
+			// g_print( "bacon_utils_get_current_workspace() = %d\n",  bacon_utils_get_current_workspace() +1 );
+			bacon_message_connection_free( connection );
+			
+			exit( EXIT_SUCCESS );
+		}
+		else 
+		{
+			g_unlink( XCFA_FILE_LOAD );
+			g_unlink( SPLIT_FILE_TMP_WAV );
+			// g_print( "\nSERVER:\nGET COMMAND LINE AND CONTINUE\n" );
+			bacon_message_connection_set_callback( connection, on_message_received, NULL );
+			GListFile = AnalyseCommandLine_set_argv( argc, &argv[0], _PARAMS_GET_ALL_OPTIONS_ );		// Get and save param-file
+			// SAVE TO:
+			// 	XCFA_FILE_LOAD
+			main_save( GListFile );
+			GListFile = libutils_remove_glist( GListFile );
+		}
+	}
+	else
+	{
+		g_warning( "Cannot create the 'gedit' connection." );
+	}
 	
+	gdk_threads_enter ();
 	if (NULL == (GtkXcfaProjet = gtk_builder_new ())) {
+		gdk_threads_leave ();
 		return (EXIT_FAILURE);
 	}
 	gtk_builder_set_translation_domain (GtkXcfaProjet, NULL);
@@ -673,6 +762,7 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	// ADMINISTRATOR MODE ?
 	if( 0 == getuid() ) {
 		wininfo_create (
+			WindMain,
 			_("MODE ADMINISTRATEUR"),
 			  "\n",
 			_("   Vous ne devriez pas utiliser   "),
@@ -681,11 +771,14 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 			  "\n",
 			"");
 	}
-	
+
 	xdg_print_list_config_path();
 	xdg_print_list_data_path();
 	
 	gtk_main ();
+
+	// bacon_message_connection_free( connection );
+	
 	gdk_threads_leave ();
 
 	exit(EXIT_SUCCESS);
