@@ -53,11 +53,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <string.h>
 #include <stdlib.h>
@@ -176,7 +171,6 @@ void Parse_remove( PARSE_TYPE p_ParseType, gboolean b_see )
 {
 	GList		*list = NULL;
 	PARSE		*Parse = NULL;
-	gboolean	BoolDestroy = FALSE;
 
 	if( p_ParseType == PARSE_TYPE_STOCKAGE_CD ) {
 		list = g_list_first (VarParse.ListParseStockCd);
@@ -217,8 +211,6 @@ void Parse_remove( PARSE_TYPE p_ParseType, gboolean b_see )
 			g_free (Parse);
 			Parse = NULL;
 			list->data = NULL;
-			
-			BoolDestroy = TRUE;
 		}
 		list = g_list_next (list);
 	}
@@ -338,7 +330,7 @@ void Parse_entry (PARSE_TYPE p_ParseType)
 	gboolean	 BoolTagOk = FALSE;
 	gboolean	 BoolSet = FALSE;
 	
-	PRINT_FUNC_LF();
+	// PRINT_FUNC_LF();
 	
 	// QUELLE LIGNE ANALYSER ?
 	if( p_ParseType == PARSE_TYPE_STOCKAGE_CD ) {
